network\_wrangler.TransitNetwork
================================

.. currentmodule:: network_wrangler

.. autoclass:: TransitNetwork

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TransitNetwork.__init__
      ~TransitNetwork.apply
      ~TransitNetwork.apply_transit_feature_change
      ~TransitNetwork.apply_transit_managed_lane
      ~TransitNetwork.empty
      ~TransitNetwork.read
      ~TransitNetwork.route_ids_in_routestxt
      ~TransitNetwork.select_transit_features
      ~TransitNetwork.select_transit_features_by_nodes
      ~TransitNetwork.set_roadnet
      ~TransitNetwork.shape_ids_in_shapestxt
      ~TransitNetwork.stop_ids_in_stopstxt
      ~TransitNetwork.transit_net_to_gdf
      ~TransitNetwork.trip_ids_in_tripstxt
      ~TransitNetwork.validate_feed
      ~TransitNetwork.validate_frequencies
      ~TransitNetwork.validate_network_keys
      ~TransitNetwork.validate_road_network_consistencies
      ~TransitNetwork.validate_transit_shapes
      ~TransitNetwork.validate_transit_stops
      ~TransitNetwork.write
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TransitNetwork.ID_SCALAR
      ~TransitNetwork.REQUIRED_FILES
      ~TransitNetwork.SHAPES_FOREIGN_KEY
      ~TransitNetwork.STOPS_FOREIGN_KEY
   
   